"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SignalsPlugin = void 0;
const signals_1 = require("../core/signals");
const logger_1 = require("../lib/logger");
const assert_browser_env_1 = require("../lib/assert-browser-env");
class SignalsPlugin {
    constructor(settings = {}) {
        this.type = 'utility';
        this.name = 'SignalsPlugin';
        this.version = '0.0.0';
        (0, assert_browser_env_1.assertBrowserEnv)();
        if (settings.enableDebugLogging) {
            logger_1.logger.enableDebugLogging();
        }
        logger_1.logger.debug('SignalsPlugin initializing', { settings });
        this.signals = new signals_1.Signals({
            disableSignalRedaction: settings.disableSignalsRedaction,
            flushAt: settings.flushAt,
            flushInterval: settings.flushInterval,
            functionHost: settings.functionHost,
            apiHost: settings.apiHost,
            maxBufferSize: settings.maxBufferSize,
            processSignal: typeof settings.processSignal === 'function'
                ? settings.processSignal.toString()
                : settings.processSignal,
        });
    }
    isLoaded() {
        return true;
    }
    async load(_ctx, analytics) {
        try {
            await this.signals.start(analytics);
            logger_1.logger.debug('SignalsPlugin loaded');
        }
        catch (err) {
            console.error(err);
        }
    }
    stop() {
        return this.signals.stop();
    }
    onSignal(cb) {
        this.signals.signalEmitter.subscribe(cb);
        return this;
    }
    addSignal(signal) {
        this.signals.signalEmitter.emit(signal);
        return this;
    }
}
exports.SignalsPlugin = SignalsPlugin;
//# sourceMappingURL=signals-plugin.js.map