import { Signals } from '../core/signals';
import { logger } from '../lib/logger';
import { assertBrowserEnv } from '../lib/assert-browser-env';
export class SignalsPlugin {
    constructor(settings = {}) {
        this.type = 'utility';
        this.name = 'SignalsPlugin';
        this.version = '0.0.0';
        assertBrowserEnv();
        if (settings.enableDebugLogging) {
            logger.enableDebugLogging();
        }
        logger.debug('SignalsPlugin initializing', { settings });
        this.signals = new Signals({
            disableSignalRedaction: settings.disableSignalsRedaction,
            flushAt: settings.flushAt,
            flushInterval: settings.flushInterval,
            functionHost: settings.functionHost,
            apiHost: settings.apiHost,
            maxBufferSize: settings.maxBufferSize,
            processSignal: typeof settings.processSignal === 'function'
                ? settings.processSignal.toString()
                : settings.processSignal,
        });
    }
    isLoaded() {
        return true;
    }
    async load(_ctx, analytics) {
        try {
            await this.signals.start(analytics);
            logger.debug('SignalsPlugin loaded');
        }
        catch (err) {
            console.error(err);
        }
    }
    stop() {
        return this.signals.stop();
    }
    onSignal(cb) {
        this.signals.signalEmitter.subscribe(cb);
        return this;
    }
    addSignal(signal) {
        this.signals.signalEmitter.emit(signal);
        return this;
    }
}
//# sourceMappingURL=signals-plugin.js.map